==> solr-solrj-4.10.4-sources.jar: org/apache/solr/common/params/DefaultSolrParams.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.solr.common.params;

import java.util.Iterator;
import java.util.LinkedHashSet;

/**
 *
 */
public class DefaultSolrParams extends SolrParams {
  protected final SolrParams params;
  protected final SolrParams defaults;

  /**
   * @deprecated (3.6) Use {@link SolrParams#wrapDefaults(SolrParams, SolrParams)} instead.
   */
  @Deprecated
  public DefaultSolrParams(SolrParams params, SolrParams defaults) {
    assert params != null && defaults != null;
    this.params = params;
    this.defaults = defaults;
  }

  @Override
  public String get(String param) {
    String val = params.get(param);
    return val!=null ? val : defaults.get(param);
  }

  @Override
  public String[] getParams(String param) {
    String[] vals = params.getParams(param);
    return vals!=null ? vals : defaults.getParams(param);
  }

  @Override
  public Iterator<String> getParameterNamesIterator() {
    // We need to compute the set of all param names in advance 
    // So we don't wind up with an iterator that returns the same
    // String more then once (SOLR-6780)
    LinkedHashSet<String> allKeys = new LinkedHashSet<>();
    for (SolrParams p : new SolrParams [] {params, defaults}) {
      Iterator<String> localKeys = p.getParameterNamesIterator();
      while (localKeys.hasNext()) {
        allKeys.add(localKeys.next());
      }
    }
    return allKeys.iterator();
  }

  @Override
  public String toString() {
    return "{params("+params+"),defaults("+defaults+")}";
  }
}

==> solr-solrj-4.11.0-20140918.114647-21-sources.jar: org/apache/solr/common/params/DefaultSolrParams.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.solr.common.params;

import java.util.Iterator;

import org.apache.solr.common.util.IteratorChain;

/**
 *
 */
public class DefaultSolrParams extends SolrParams {
  protected final SolrParams params;
  protected final SolrParams defaults;

  /**
   * @deprecated (3.6) Use {@link SolrParams#wrapDefaults(SolrParams, SolrParams)} instead.
   */
  @Deprecated
  public DefaultSolrParams(SolrParams params, SolrParams defaults) {
    assert params != null && defaults != null;
    this.params = params;
    this.defaults = defaults;
  }

  @Override
  public String get(String param) {
    String val = params.get(param);
    return val!=null ? val : defaults.get(param);
  }

  @Override
  public String[] getParams(String param) {
    String[] vals = params.getParams(param);
    return vals!=null ? vals : defaults.getParams(param);
  }

  @Override
  public Iterator<String> getParameterNamesIterator() {
    final IteratorChain<String> c = new IteratorChain<>();
    c.addIterator(defaults.getParameterNamesIterator());
    c.addIterator(params.getParameterNamesIterator());
    return c;
  }

  @Override
  public String toString() {
    return "{params("+params+"),defaults("+defaults+")}";
  }
}
